Index: main/waeup.sirp/trunk/src/waeup/sirp/students/interfaces.py
===================================================================
--- main/waeup.sirp/trunk/src/waeup/sirp/students/interfaces.py	(revision 7319)
+++ main/waeup.sirp/trunk/src/waeup/sirp/students/interfaces.py	(revision 7321)
@@ -20,5 +20,5 @@
 from zope import schema
 from waeup.sirp.interfaces import (
-    IWAeUPObject, academic_sessions_vocab, validate_email)
+    ISIRPObject, academic_sessions_vocab, validate_email)
 from waeup.sirp.schema import TextLineChoice
 from waeup.sirp.university.vocabularies import CourseSource, study_modes
@@ -56,5 +56,5 @@
         """
 
-class IStudentsContainer(IWAeUPObject):
+class IStudentsContainer(ISIRPObject):
     """A students container contains university students.
 
@@ -95,5 +95,5 @@
         """
 
-class IStudentNavigation(IWAeUPObject):
+class IStudentNavigation(ISIRPObject):
     """Interface needed for student navigation.
 
@@ -104,5 +104,5 @@
         """
 
-class IStudentBase(IWAeUPObject):
+class IStudentBase(ISIRPObject):
     """Representation of student base data.
 
@@ -173,5 +173,5 @@
         )
 
-class IStudentClearance(IWAeUPObject):
+class IStudentClearance(ISIRPObject):
     """Representation of student clearance data.
 
@@ -194,5 +194,5 @@
         )
 
-class IStudentPersonal(IWAeUPObject):
+class IStudentPersonal(ISIRPObject):
     """Representation of student personal data.
 
@@ -228,5 +228,5 @@
         )
 
-class IStudentStudyCourse(IWAeUPObject):
+class IStudentStudyCourse(ISIRPObject):
     """A container for student study levels.
 
@@ -295,5 +295,5 @@
         )
 
-class IStudentStudyLevel(IWAeUPObject):
+class IStudentStudyLevel(ISIRPObject):
     """A container for course tickets.
 
@@ -317,5 +317,5 @@
         )
 
-class ICourseTicket(IWAeUPObject):
+class ICourseTicket(ISIRPObject):
     """A course ticket.
 
@@ -362,10 +362,10 @@
         )
 
-class IStudentAccommodation(IWAeUPObject):
+class IStudentAccommodation(ISIRPObject):
     """A container for student accommodation objects.
 
     """
 
-class IBedTicket(IWAeUPObject):
+class IBedTicket(ISIRPObject):
     """A ticket for accommodation booking.
 
Index: main/waeup.sirp/trunk/src/waeup/sirp/students/student.py
===================================================================
--- main/waeup.sirp/trunk/src/waeup/sirp/students/student.py	(revision 7319)
+++ main/waeup.sirp/trunk/src/waeup/sirp/students/student.py	(revision 7321)
@@ -27,5 +27,5 @@
 from waeup.sirp.interfaces import (
     IObjectHistory, IUserAccount, IFileStoreNameChooser, IFileStoreHandler)
-from waeup.sirp.image import WAeUPImageFile
+from waeup.sirp.image import SIRPImageFile
 from waeup.sirp.imagestorage import DefaultFileStoreHandler
 from waeup.sirp.students.interfaces import (
@@ -257,4 +257,4 @@
             StudentFileStoreHandler, self).createFile(
             store, root,  filename, file_id, file)
-        return file, path, WAeUPImageFile(
+        return file, path, SIRPImageFile(
             file_obj.filename, file_obj.data)
Index: main/waeup.sirp/trunk/src/waeup/sirp/students/vocabularies.py
===================================================================
--- main/waeup.sirp/trunk/src/waeup/sirp/students/vocabularies.py	(revision 7319)
+++ main/waeup.sirp/trunk/src/waeup/sirp/students/vocabularies.py	(revision 7321)
@@ -25,9 +25,9 @@
 from zc.sourcefactory.basic import BasicSourceFactory
 from zc.sourcefactory.contextual import BasicContextualSourceFactory
-from waeup.sirp.interfaces import SimpleWAeUPVocabulary
+from waeup.sirp.interfaces import SimpleSIRPVocabulary
 from waeup.sirp.students.lgas import LGAS
 from waeup.sirp.university.vocabularies import course_levels
 
-lgas_vocab = SimpleWAeUPVocabulary(
+lgas_vocab = SimpleSIRPVocabulary(
     *sorted([(x[1],x[0]) for x in LGAS]))
 
@@ -71,5 +71,5 @@
         return title
 
-verdicts = SimpleWAeUPVocabulary(
+verdicts = SimpleSIRPVocabulary(
     ('not yet','0'),
     ('Successful student','A'),
Index: main/waeup.sirp/trunk/src/waeup/sirp/students/workflow.py
===================================================================
--- main/waeup.sirp/trunk/src/waeup/sirp/students/workflow.py	(revision 7319)
+++ main/waeup.sirp/trunk/src/waeup/sirp/students/workflow.py	(revision 7321)
@@ -5,8 +5,8 @@
 from hurry.workflow.interfaces import IWorkflowState, IWorkflowTransitionEvent
 from waeup.sirp.interfaces import (
-    IObjectHistory, IWAeUPWorkflowInfo,
+    IObjectHistory, ISIRPWorkflowInfo,
     CREATED, ADMITTED, CLEARANCE, REQUESTED, CLEARED, PAID, RETURNING,
     REGISTERED, VALIDATED)
-from waeup.sirp.workflow import WAeUPWorkflow, WAeUPWorkflowInfo
+from waeup.sirp.workflow import SIRPWorkflow, SIRPWorkflowInfo
 from waeup.sirp.utils.helpers import get_current_principal
 from waeup.sirp.students.interfaces import IStudent
@@ -152,5 +152,5 @@
 UNLOCK_CLEARANCE_TRANS = ('reset3', 'reset4', 'start_clearance')
 
-registration_workflow = WAeUPWorkflow(REGISTRATION_TRANSITIONS)
+registration_workflow = SIRPWorkflow(REGISTRATION_TRANSITIONS)
 
 class RegistrationWorkflowState(WorkflowState, grok.Adapter):
@@ -163,9 +163,9 @@
     state_id = 'wf.registration.id'
 
-class RegistrationWorkflowInfo(WAeUPWorkflowInfo, grok.Adapter):
+class RegistrationWorkflowInfo(SIRPWorkflowInfo, grok.Adapter):
     """Adapter to adapt Student objects to workflow info objects.
     """
     grok.context(IStudent)
-    grok.provides(IWAeUPWorkflowInfo)
+    grok.provides(ISIRPWorkflowInfo)
 
     def __init__(self, context):

Index: main/waeup.sirp/trunk/src/waeup/sirp/students/browser.py
===================================================================
--- main/waeup.sirp/trunk/src/waeup/sirp/students/browser.py	(revision 7319)
+++ main/waeup.sirp/trunk/src/waeup/sirp/students/browser.py	(revision 7321)
@@ -32,5 +32,5 @@
 from waeup.sirp.accesscodes.workflow import USED
 from waeup.sirp.browser import (
-    WAeUPPage, WAeUPEditFormPage, WAeUPAddFormPage, WAeUPDisplayFormPage,
+    SIRPPage, SIRPEditFormPage, SIRPAddFormPage, SIRPDisplayFormPage,
     ContactAdminForm)
 from waeup.sirp.browser.breadcrumbs import Breadcrumb
@@ -39,5 +39,5 @@
     ManageActionButton, AddActionButton)
 from waeup.sirp.interfaces import (
     IWAeUPObject, IUserAccount, IExtFileStore, IPasswordValidator, IContactForm)
 from waeup.sirp.widgets.datewidget import (
     FriendlyDateWidget, FriendlyDateDisplayWidget,
@@ -155,5 +155,5 @@
         return self.context.level_title
 
-class StudentsContainerPage(WAeUPPage):
+class StudentsContainerPage(SIRPPage):
     """The standard view for student containers.
     """
@@ -188,6 +188,6 @@
         return
 
-class SetPasswordPage(WAeUPPage):
-    grok.context(IWAeUPObject)
+class SetPasswordPage(SIRPPage):
+    grok.context(ISIRPObject)
     grok.name('setpassword')
     grok.require('waeup.Public')
@@ -253,5 +253,5 @@
 
 
-class StudentsContainerManagePage(WAeUPPage):
+class StudentsContainerManagePage(SIRPPage):
     """The manage page for student containers.
     """
@@ -310,5 +310,5 @@
     target = 'addstudent'
 
-class StudentAddFormPage(WAeUPAddFormPage):
+class StudentAddFormPage(SIRPAddFormPage):
     """Add-form to add a student.
     """
@@ -331,5 +331,5 @@
         return
 
-class StudentBaseDisplayFormPage(WAeUPDisplayFormPage):
+class StudentBaseDisplayFormPage(SIRPDisplayFormPage):
     """ Page to display student base data
     """
@@ -406,5 +406,5 @@
     target = 'manage_base'
 
-class StudentBaseManageFormPage(WAeUPEditFormPage):
+class StudentBaseManageFormPage(SIRPEditFormPage):
     """ View to manage student base data
     """
@@ -467,5 +467,5 @@
         return
 
-class StudentClearanceDisplayFormPage(WAeUPDisplayFormPage):
+class StudentClearanceDisplayFormPage(SIRPDisplayFormPage):
     """ Page to display student clearance data
     """
@@ -552,5 +552,5 @@
             self.context.getStudent(), studentview)
 
-class StudentClearanceManageFormPage(WAeUPEditFormPage):
+class StudentClearanceManageFormPage(SIRPEditFormPage):
     """ Page to edit student clearance data
     """
@@ -622,5 +622,5 @@
         return
 
-class StudentPersonalDisplayFormPage(WAeUPDisplayFormPage):
+class StudentPersonalDisplayFormPage(SIRPDisplayFormPage):
     """ Page to display student personal data
     """
@@ -644,5 +644,5 @@
     target = 'edit_personal'
 
-class StudentPersonalManageFormPage(WAeUPEditFormPage):
+class StudentPersonalManageFormPage(SIRPEditFormPage):
     """ Page to edit student clearance data
     """
@@ -660,5 +660,5 @@
         return
 
-class StudyCourseDisplayFormPage(WAeUPDisplayFormPage):
+class StudyCourseDisplayFormPage(SIRPDisplayFormPage):
     """ Page to display the student study course data
     """
@@ -703,5 +703,5 @@
     target = 'manage'
 
-class StudyCourseManageFormPage(WAeUPEditFormPage):
+class StudyCourseManageFormPage(SIRPEditFormPage):
     """ Page to edit the student study course data
     """
@@ -773,5 +773,5 @@
         return
 
-class StudyLevelDisplayFormPage(WAeUPDisplayFormPage):
+class StudyLevelDisplayFormPage(SIRPDisplayFormPage):
     """ Page to display student study levels
     """
@@ -854,5 +854,5 @@
     target = 'manage'
 
-class StudyLevelManageFormPage(WAeUPEditFormPage):
+class StudyLevelManageFormPage(SIRPEditFormPage):
     """ Page to edit the student study level data
     """
@@ -913,5 +913,5 @@
         return
 
-class CourseTicketAddFormPage(WAeUPAddFormPage):
+class CourseTicketAddFormPage(SIRPAddFormPage):
     """Add a course ticket.
     """
@@ -956,5 +956,5 @@
         self.redirect(self.url(self.context))
 
-class CourseTicketDisplayFormPage(WAeUPDisplayFormPage):
+class CourseTicketDisplayFormPage(SIRPDisplayFormPage):
     """ Page to display course tickets
     """
@@ -983,5 +983,5 @@
     target = 'manage'
 
-class CourseTicketManageFormPage(WAeUPEditFormPage):
+class CourseTicketManageFormPage(SIRPEditFormPage):
     """ Page to manage course tickets
     """
@@ -1007,5 +1007,5 @@
 
 # We don't need the display form page yet
-#class PaymentsDisplayFormPage(WAeUPDisplayFormPage):
+#class PaymentsDisplayFormPage(SIRPDisplayFormPage):
 #    """ Page to display the student payments
 #    """
@@ -1028,5 +1028,5 @@
 
 # This manage form page is for both students and students officers.
-class PaymentsManageFormPage(WAeUPEditFormPage):
+class PaymentsManageFormPage(SIRPEditFormPage):
     """ Page to manage the student payments
     """
@@ -1093,5 +1093,5 @@
 #    target = 'manage'
 
-class OnlinePaymentAddFormPage(WAeUPAddFormPage):
+class OnlinePaymentAddFormPage(SIRPAddFormPage):
     """ Page to add an online payment ticket
     """
@@ -1152,5 +1152,5 @@
         return
 
-class OnlinePaymentDisplayFormPage(WAeUPDisplayFormPage):
+class OnlinePaymentDisplayFormPage(SIRPDisplayFormPage):
     """ Page to view an online payment ticket
     """
@@ -1279,5 +1279,5 @@
 
 # We don't need the display form page yet
-#class AccommodationDisplayFormPage(WAeUPDisplayFormPage):
+#class AccommodationDisplayFormPage(SIRPDisplayFormPage):
 #    """ Page to display the student accommodation data
 #    """
@@ -1295,5 +1295,5 @@
 
 # This manage form page is for both students and students officers.
-class AccommodationManageFormPage(WAeUPEditFormPage):
+class AccommodationManageFormPage(SIRPEditFormPage):
     """ Page to manage bed tickets.
     """
@@ -1358,5 +1358,5 @@
     target = 'add'
 
-class BedTicketAddPage(WAeUPPage):
+class BedTicketAddPage(SIRPPage):
     """ Page to add an online payment ticket
     """
@@ -1449,5 +1449,5 @@
         return
 
-class BedTicketDisplayFormPage(WAeUPDisplayFormPage):
+class BedTicketDisplayFormPage(SIRPDisplayFormPage):
     """ Page to display bed tickets
     """
@@ -1576,5 +1576,5 @@
         return
 
-class StudentHistoryPage(WAeUPPage):
+class StudentHistoryPage(SIRPPage):
     """ Page to display student clearance data
     """
@@ -1624,5 +1624,5 @@
         return self.view.url(self.view.context, self.target)
 
-class StudentBaseEditFormPage(WAeUPEditFormPage):
+class StudentBaseEditFormPage(SIRPEditFormPage):
     """ View to edit student base data
     """
@@ -1641,5 +1641,5 @@
         return
 
-class StudentChangePasswordPage(WAeUPEditFormPage):
+class StudentChangePasswordPage(SIRPEditFormPage):
     """ View to manage student base data
     """
@@ -1668,5 +1668,5 @@
         return
 
-class StudentFilesUploadPage(WAeUPPage):
+class StudentFilesUploadPage(SIRPPage):
     """ View to upload files by student
     """
@@ -1701,5 +1701,5 @@
         return self.view.url(self.view.context, self.target)
 
-class StartClearancePage(WAeUPPage):
+class StartClearancePage(SIRPPage):
     grok.context(IStudent)
     grok.name('start_clearance')
@@ -1823,5 +1823,5 @@
         return
 
-class RequestClearancePage(WAeUPPage):
+class RequestClearancePage(SIRPPage):
     grok.context(IStudent)
     grok.name('request_clearance')
@@ -1870,5 +1870,5 @@
         return self.view.url(self.view.context, self.target)
 
-class StartCourseRegistrationPage(WAeUPPage):
+class StartCourseRegistrationPage(SIRPPage):
     grok.context(IStudentStudyCourse)
     grok.name('start_course_registration')
@@ -1939,5 +1939,5 @@
         return self.view.url(self.view.context, self.target)
 
-class AddStudyLevelFormPage(WAeUPEditFormPage):
+class AddStudyLevelFormPage(SIRPEditFormPage):
     """ Page for students to add current study levels
     """
@@ -1995,5 +1995,5 @@
         return self.view.url(self.view.context, self.target)
 
-class StudyLevelEditFormPage(WAeUPEditFormPage):
+class StudyLevelEditFormPage(SIRPEditFormPage):
     """ Page to edit the student study level data by students
     """
@@ -39,5 +39,5 @@
     ManageActionButton, AddActionButton)
 from waeup.sirp.interfaces import (
-    IWAeUPObject, IUserAccount, IExtFileStore, IPasswordValidator, IContactForm)
+    ISIRPObject, IUserAccount, IExtFileStore, IPasswordValidator, IContactForm)
 from waeup.sirp.widgets.datewidget import (
     FriendlyDateWidget, FriendlyDateDisplayWidget,
Index: main/waeup.sirp/trunk/src/waeup/sirp/students/viewlets.py
===================================================================
--- main/waeup.sirp/trunk/src/waeup/sirp/students/viewlets.py	(revision 7319)
+++ main/waeup.sirp/trunk/src/waeup/sirp/students/viewlets.py	(revision 7321)
@@ -21,5 +21,5 @@
 from zope.interface import Interface
 from waeup.sirp.interfaces import (
-    IWAeUPObject, IExtFileStore, IFileStoreNameChooser)
+    ISIRPObject, IExtFileStore, IFileStoreNameChooser)
 from waeup.sirp.utils.helpers import string_from_bytes, file_size
 from waeup.sirp.browser import DEFAULT_IMAGE_PATH
@@ -32,5 +32,5 @@
 from waeup.sirp.students.interfaces import IStudent, IStudentClearance
 
-grok.context(IWAeUPObject) # Make IWAeUPObject the default context
+grok.context(ISIRPObject) # Make ISIRPObject the default context
 grok.templatedir('browser_templates')
 
@@ -47,5 +47,5 @@
     grok.baseclass()
     grok.viewletmanager(StudentManageSidebar)
-    grok.context(IWAeUPObject)
+    grok.context(ISIRPObject)
     grok.view(Interface)
     grok.order(5)
@@ -108,5 +108,5 @@
     grok.baseclass()
     grok.viewletmanager(StudentMenu)
-    grok.context(IWAeUPObject)
+    grok.context(ISIRPObject)
     grok.view(Interface)
     grok.order(5)
@@ -162,5 +162,5 @@
     """
 
-    grok.context(IWAeUPObject)
+    grok.context(ISIRPObject)
     grok.order(4)
     grok.require('waeup.viewStudentsTab')